#include <bits/stdc++.h>

using namespace std;

struct point {
    long long x, y;
    point() {}
    point(long long x, long long y) : x(x), y(y) {}
};

struct line {
    long long a, b, c;
    line(long long a, long long b, long long c) : a(a), b(b), c(c) {}
    line(point p1, point p2) : a(p1.y - p2.y), b(p2.x - p1.x), c(p1.x * p2.y - p2.x * p1.y) {}

    double distance(point p) {
        return abs(a * p.x + b * p.y + c) / sqrt(a * a + b * b);
    }
};

double solve(point p1, vector<point> points, long long x, long long y) {
    line l(p1, point(x, y));
    double dist = 0;
    for (int i = 0; i < points.size(); i++) {
        dist += l.distance(points[i]);
    }
    return dist;
}

const long long MAX_COORD = 1e9;

pair<double, long long> solve(point p1, vector<point> points, long long x) {
    long long ly = -MAX_COORD, ry = MAX_COORD;
    while (ry - ly > 2) {
        // cerr << "Y: " << ly << " " << ry << endl;
        long long m1y = (2 * ly + ry) / 3;
        long long m2y = (ly + 2 * ry) / 3;
        if (solve(p1, points, x, m1y) < solve(p1, points, x, m2y)) {
            ry = m2y;
        } else {
            ly = m1y;
        }
    }
    double d1 = solve(p1, points, x, ly);
    double d2 = solve(p1, points, x, ry);
    double d3 = solve(p1, points, x, (ly + ry) / 2);
    if (d1 <= d2 && d1 <= d3) {
        return {d1, ly};
    } else if (d2 <= d3 && d2 <= d1) {
        return {d2, ry};
    } else {
        return {d3, (ly + ry) / 2};
    }
}

pair<double, pair<long long, long long>>  solve(point p1, vector<point> points) {
    long long lx = -MAX_COORD, rx = MAX_COORD;
    while (rx - lx > 2) {
        // cerr << "X: " << lx << " " << rx << endl;
        long long m1x = (2 * lx + rx) / 3;
        long long m2x = (lx + 2 * rx) / 3;
        if (solve(p1, points, m1x).first < solve(p1, points, m2x).first) {
            rx = m2x;
        } else {
            lx = m1x;
        }
    }
    auto [d1, ly] = solve(p1, points, lx);
    auto [d2, ry] = solve(p1, points, rx);
    auto [d3, m] = solve(p1, points, (lx + rx) / 2);
    
    if (d1 <= d2 && d1 <= d3) {
        return {d1, {lx, ly}};
    } else if (d2 <= d3 && d2 <= d1) {
        return {d2, {rx, ry}}; 
    } else {
        return {d3, {(lx + rx) / 2, m}};
    }
}

int main() {
    vector<point> points(3);
    for (int i = 0; i < 3; i++) {
        cin >> points[i].x >> points[i].y;
    }
    auto [d1, r1] = solve(points[0], points);
    auto [d2, r2] = solve(points[1], points);
    auto [d3, r3] = solve(points[2], points);
    cerr << d1 << " " << d2 << " " << d3 << endl;
    if (d1 <= d2 && d1 <= d3) {
        cout << points[0].x << " " << points[0].y << " ";
        cout << r1.first << " " << r1.second << endl;
    } else if (d2 <= d1 && d2 <= d3) {
        cout << points[1].x << " " << points[1].y << " ";
        cout << r2.first << " " << r2.second << endl;
    } else if (d3 <= d1 && d3 <= d2) {
        cout << points[2].x << " " << points[2].y << " ";
        cout << r3.first << " " << r3.second << endl;
    }
}
